Topic Model Browser

#### Settings

Use these controls to adjust how much information is displayed on some of the browser pages.

Show hidden topics
topic top words in lists
topic top words on the topic page
top articles on the topic page
Display stacked overview as a streamgraph

topic | variation | top words | proportion of corpus
--- | --- | --- | ---

Model-browser interface by Andrew Goldstone; source available on github. Made using d3.js and Bootstrap. Zip support using JSZip.

Select a topic from the "Topic" menu above.

##

###

### Top words

Word | Weight
--- | ---

### Conditional probability of words in topic of topic

Click a bar to limit to the documents it represents

### Top documents

There are no documents containing this topic.

Document |  | % | Tokens
--- | --- | --- | ---

Choose a specific document to view from the bibliography or from a topic page.

Below: the last-viewed document. Stable link to this view:

##

... tokens. View Metadata

Topic | Top words |  | % | Tokens
--- | --- | --- | --- | ---

Choose a specific word to view from the list of all words or from a topic page.

Below: the last-viewed word. Stable link to this view:

Choose a word:

## Prominent topics for

Click row labels to go to the corresponding topic page; click a word to show the topic list for that word.

There are no topics in which this word is prominent.

jump to:

top

## All words prominent in any topic

Words not prominent in any topic are not listed

#### Document Metadata

# Loading...